/*@
 * Copyright(c) 1995-1997 Gregory M. Messner
 * All rights reserved
 *
 * Permission to use, copy, modify and distribute this material for
 * non-commercial personal and educational use without fee is hereby
 * granted, provided that the above copyright notice and this permission 
 * notice appear in all copies, and that the name of Gregory M. Messner
 * not be used in advertising or publicity pertaining to this material
 * without the specific, prior written permission of Gregory M. Messner 
 * or an authorized representative.
 *
 * GREGORY M. MESSNER MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, 
 * EXPRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST INFRINGEMENT OF PATENTS
 * OR OTHER INTELLECTUAL PROPERTY RIGHTS. THE SOFTWARE IS PROVIDED "AS IS",
 * AND IN NO EVENT SHALL GREGORY M. MESSNER BE LIABLE FOR ANY DAMAGES,
 * INCLUDING ANY LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES
 * RELATING TO THE SOFTWARE.
 *
 */


#include	<stdio.h>

#include	<Xm/Xm.h>
#include	"FastLabel.h"
#include	<Xm/Form.h>

main(argc, argv)
int	argc;
char	**argv;
{	
Widget	 	topLevel;
Widget		form;	
Widget		fastlabel;
Widget		button;
XtAppContext	app;




	topLevel = XtVaAppInitialize(&app,
		"Test",
		NULL, 0,
		&argc, argv,
		NULL,
		NULL);

	form = XtVaCreateWidget(NULL, 
		xmFormWidgetClass, topLevel, NULL);

	fastlabel = XtVaCreateManagedWidget(NULL, 
		xgFastLabelWidgetClass, form,
		XmNleftAttachment, XmATTACH_FORM,
		XmNrightAttachment, XmATTACH_FORM,
		XmNtopAttachment, XmATTACH_FORM,
		XmNbottomAttachment, XmATTACH_FORM, 
		XmNstring, "This is a FastLabel (rotated 270 degrees)",
		XmNalignment, XmALIGNMENT_CENTER,
		XgNrotation, 270,
		XmNrecomputeSize, True,
		NULL);

	XtManageChild(form);

	XtRealizeWidget(topLevel);

	XtAppMainLoop(app);
}
